==> astro_ghost-0.2.4.tar.gz: astro_ghost-0.2.4/astro_ghost/starSeparation.py <==
from sklearn import svm
import seaborn as sns
import matplotlib.pyplot as plt
from astro_ghost.stellarLocus import *
import pickle
import pkg_resources

def separateStars_STRM(df, model_path='.', plot=False, verbose=False, starcut='gentle'):
    """Star-galaxy separation, using a random forest trained on the PS1-STRM-classified star
       and galaxy labels given in Beck et al., 2021.

    Parameters
    ----------
    df : Pandas DataFrame
        Dataframe of PS1 sources.
    model_path : str
        Filepath to the saved random forest model.
    plot : bool
        If True, shows the separated stars and galaxies in Ap - Kron vs Ap Mag space.
    verbose : bool
        If true, print details of the classification routine.
    starcut : str
        Strings corresponding to the classification thresholds required to classify a star as such.
        Options are 'gentle' (P>0.8), normal (P>0.5), and aggressive (P>0.3).

    Returns
    -------
    df_gals : Pandas DataFrame
        PS1 sources classified as galaxies.
    df_stars : Pandas DataFrame
        PS1 sources classified as stars.

    """
    # remove all sources with bad values for any required PS1 properties
    df_dropped = df.dropna(subset=['7DCD','gApMag','gApMag_gKronMag','rApMag','rApMag_rKronMag','iApMag', 'iApMag_iKronMag'])
    only_na = df[~df.index.isin(df_dropped.index)]
    unsure = df_dropped.reset_index(drop=True)

    # load random forest model
    modelName = "Star_Galaxy_RealisticModel_GHOST_PS1ClassLabels.sav"
    stream = pkg_resources.resource_stream(__name__, modelName)
    if verbose:
        print("Loading model %s."%modelName)
    model = pickle.load(stream)

    # plot the distribution of objects before classifying
    if plot:
        sns.set_style("dark")
        sns.set_context("talk")

        plt.figure(figsize=(10,8))
        plt.plot(unsure['iApMag'], unsure['iApMag_iKronMag'], 'o', alpha=0.1)
        plt.xlabel(r"Ap Mag, $i$")
        plt.ylabel(r"Ap - Kron Mag, $i$")
        plt.savefig("TNS_NoClassificationInfo.pdf")

    unsure = unsure.dropna(subset=['7DCD','gApMag','gApMag_gKronMag','rApMag','rApMag_rKronMag','iApMag', 'iApMag_iKronMag'])
    if len(unsure) <1:
        if verbose:
            print("No sources in field with feature values, skipping star/galaxy separation...")
        return df, unsure
    test_X = np.asarray(unsure[['7DCD','gApMag','gApMag_gKronMag','rApMag','rApMag_rKronMag','iApMag', 'iApMag_iKronMag']])

    # define probability threshold for classification
    if starcut is 'normal':
        test_y = model.predict(test_X)
    elif starcut is 'aggressive':
        test_y = model.predict_proba(test_X)[:,1] > 0.3
    elif starcut is 'gentle':
        test_y = model.predict_proba(test_X)[:,1] > 0.8
    else:
        print("Error! I didn't understand your starcut option.")
    unsure['class'] = test_y
    test_stars = unsure[unsure['class'] == 1]
    test_gals = unsure[unsure['class'] == 0]

    # plot the distribution of classified stars and galaxies.
    if plot:
        c_gals = '#087e8b'
        c_stars = '#ffbf00'

        plt.figure(num=None, figsize=(8, 6), dpi=80, facecolor='w', edgecolor='k')
        sns.kdeplot(test_gals['iApMag'], test_gals['iApMag_iKronMag'], n_levels=20, shade_lowest=False, shade=False,label='Galaxies', color=c_gals, alpha=0.5,legend=True);
        if len(test_stars) > 1:
            sns.kdeplot(test_stars['iApMag'], test_stars['iApMag_iKronMag'], n_levels=20, shade_lowest=False, shade=False,label='Stars', color=c_stars, alpha=0.5);
        plt.legend()
        plt.xlim(xmin=13,xmax=23)
        plt.ylim(ymin=-1,ymax=5)
        plt.xlabel("Ap Magnitude, $i$",fontsize=16)
        plt.ylabel("Ap - Kron Magnitude, $i$",fontsize=16)

        plt.savefig("TNS_STRM_Stars_vs_Gals_Contours.pdf")

        plt.figure(num=None, figsize=(8, 6), dpi=80, facecolor='w', edgecolor='k')
        ax = sns.distplot(test_gals['iApMag_iKronMag'],bins=np.linspace(-1, 7, num=100),label='Galaxies',kde=False,hist_kws={"color": c_gals});
        if len(test_stars) > 1:
            sns.distplot(test_stars['iApMag_iKronMag'],bins=np.linspace(-1, 7, num=100),label='Stars',kde=False,hist_kws={"color": c_stars});
        sns.distplot(unsure['iApMag_iKronMag'],bins=np.linspace(-1, 7, num=100),label='Total',kde=False,hist_kws={"histtype": "step", "linewidth": 1, "alpha": 1, "color": "black"});

        plt.xlim(-1, 3)
        plt.xlabel("Ap - Kron Mag, $i$",fontsize=16)
        plt.xlim()
        plt.ylabel("N",fontsize=16)
        plt.legend(fontsize=16)
        plt.savefig("TNS_iAp_iKronMag_Histogram.pdf")

    # removing the ones where we have no NED identification
    df = df[~df['NED_type'].isnull()]

    # Adding back in the ones we identified as galaxies from our clustering above:
    df_gals = pd.concat([test_gals, only_na])
    df_gals.reset_index(inplace=True, drop=True)
    df_stars = test_stars.drop_duplicates()
    return df_gals, df_stars

def separateStars_South(df, plot=0, verbose=0, starcut='gentle'):
    """Star-galaxy separation in the southern hemisphere, using a simple
       SkyMapper_StarClass threshold cut.

    Parameters
    ----------
    df : Pandas DataFrame
        Dataframe of PS1 sources.
    plot : bool
        If True, shows the separated stars and galaxies in Ap - Kron vs Ap Mag space.
    verbose : bool
        If true, print details of the classification routine.
    starcut : str
        Strings corresponding to the classification thresholds required to classify a star as such.
        Options are 'gentle' (P>0.8), normal (P>0.5), and aggressive (P>0.3).

    Returns
    -------
    df_gals : Pandas DataFrame
        PS1 sources classified as galaxies.
    df_stars : Pandas DataFrame
        PS1 sources classified as stars.

    """
    df_dropped = df[df['SkyMapper_StarClass']>0]
    only_na = df[~df.index.isin(df_dropped.index)]
    if starcut is 'normal':
        df_stars = df_dropped[df_dropped['SkyMapper_StarClass']>=0.5]
    elif starcut is 'aggressive':
        df_stars = df_dropped[df_dropped['SkyMapper_StarClass']>=0.3]
    elif starcut is 'gentle':
        df_stars = df_dropped[df_dropped['SkyMapper_StarClass']>=0.8]
    df_class_gals = df_dropped[~df_dropped.index.isin(df_stars.index)]
    df_stars.reset_index(inplace=True, drop=True)
    df_class_gals.reset_index(inplace=True, drop=True)
    df_gals = pd.concat([df_class_gals, only_na], ignore_index=True).drop_duplicates()
    return df_gals, df_stars

==> astro_ghost-0.2.5.tar.gz: astro_ghost-0.2.5/astro_ghost/starSeparation.py <==
from sklearn import svm
import seaborn as sns
import matplotlib.pyplot as plt
from astro_ghost.stellarLocus import *
import pickle
import pkg_resources

def separateStars_STRM(df, model_path='.', plot=False, verbose=False, starcut='gentle'):
    """Star-galaxy separation, using a random forest trained on the PS1-STRM-classified star
       and galaxy labels given in Beck et al., 2021.

    :param df: Dataframe of PS1 sources.
    :type df: Pandas DataFrame
    :param model_path: Filepath to the saved random forest model.
    :type model_path: str, optional
    :param plot: If True, shows the separated stars and galaxies in Ap - Kron vs Ap Mag space.
    :type plot: bool, optional
    :param verbose: If true, print details of the classification routine.
    :type verbose: bool, optional
    :param starcut: Labels corresponding to the classification thresholds required to classify a star as such.
        Options are 'gentle' (P>0.8), normal (P>0.5), and aggressive (P>0.3).
    :type starcut: str

    :return: A dataframe of sources classified as galaxies.
    :rtype: Pandas DataFrame
    :return: A dataframe of sources classified as stars.
    :rtype: Pandas DataFrame
    """

    # remove all sources with bad values for any required PS1 properties
    df_dropped = df.dropna(subset=['7DCD','gApMag','gApMag_gKronMag','rApMag','rApMag_rKronMag','iApMag', 'iApMag_iKronMag'])
    only_na = df[~df.index.isin(df_dropped.index)]
    unsure = df_dropped.reset_index(drop=True)

    # load random forest model
    modelName = "Star_Galaxy_RealisticModel_GHOST_PS1ClassLabels.sav"
    stream = pkg_resources.resource_stream(__name__, modelName)
    if verbose:
        print("Loading model %s."%modelName)
    model = pickle.load(stream)

    # plot the distribution of objects before classifying
    if plot:
        sns.set_style("dark")
        sns.set_context("talk")

        plt.figure(figsize=(10,8))
        plt.plot(unsure['iApMag'], unsure['iApMag_iKronMag'], 'o', alpha=0.1)
        plt.xlabel(r"Ap Mag, $i$")
        plt.ylabel(r"Ap - Kron Mag, $i$")
        plt.savefig("TNS_NoClassificationInfo.pdf")

    unsure = unsure.dropna(subset=['7DCD','gApMag','gApMag_gKronMag','rApMag','rApMag_rKronMag','iApMag', 'iApMag_iKronMag'])
    if len(unsure) <1:
        if verbose:
            print("No sources in field with feature values, skipping star/galaxy separation...")
        return df, unsure
    test_X = np.asarray(unsure[['7DCD','gApMag','gApMag_gKronMag','rApMag','rApMag_rKronMag','iApMag', 'iApMag_iKronMag']])

    # define probability threshold for classification
    if starcut is 'normal':
        test_y = model.predict(test_X)
    elif starcut is 'aggressive':
        test_y = model.predict_proba(test_X)[:,1] > 0.3
    elif starcut is 'gentle':
        test_y = model.predict_proba(test_X)[:,1] > 0.8
    else:
        print("Error! I didn't understand your starcut option.")
    unsure['class'] = test_y
    test_stars = unsure[unsure['class'] == 1]
    test_gals = unsure[unsure['class'] == 0]

    # plot the distribution of classified stars and galaxies.
    if plot:
        c_gals = '#087e8b'
        c_stars = '#ffbf00'

        plt.figure(num=None, figsize=(8, 6), dpi=80, facecolor='w', edgecolor='k')
        sns.kdeplot(test_gals['iApMag'], test_gals['iApMag_iKronMag'], n_levels=20, shade_lowest=False, shade=False,label='Galaxies', color=c_gals, alpha=0.5,legend=True);
        if len(test_stars) > 1:
            sns.kdeplot(test_stars['iApMag'], test_stars['iApMag_iKronMag'], n_levels=20, shade_lowest=False, shade=False,label='Stars', color=c_stars, alpha=0.5);
        plt.legend()
        plt.xlim(xmin=13,xmax=23)
        plt.ylim(ymin=-1,ymax=5)
        plt.xlabel("Ap Magnitude, $i$",fontsize=16)
        plt.ylabel("Ap - Kron Magnitude, $i$",fontsize=16)

        plt.savefig("TNS_STRM_Stars_vs_Gals_Contours.pdf")

        plt.figure(num=None, figsize=(8, 6), dpi=80, facecolor='w', edgecolor='k')
        ax = sns.distplot(test_gals['iApMag_iKronMag'],bins=np.linspace(-1, 7, num=100),label='Galaxies',kde=False,hist_kws={"color": c_gals});
        if len(test_stars) > 1:
            sns.distplot(test_stars['iApMag_iKronMag'],bins=np.linspace(-1, 7, num=100),label='Stars',kde=False,hist_kws={"color": c_stars});
        sns.distplot(unsure['iApMag_iKronMag'],bins=np.linspace(-1, 7, num=100),label='Total',kde=False,hist_kws={"histtype": "step", "linewidth": 1, "alpha": 1, "color": "black"});

        plt.xlim(-1, 3)
        plt.xlabel("Ap - Kron Mag, $i$",fontsize=16)
        plt.xlim()
        plt.ylabel("N",fontsize=16)
        plt.legend(fontsize=16)
        plt.savefig("TNS_iAp_iKronMag_Histogram.pdf")

    # removing the ones where we have no NED identification
    df = df[~df['NED_type'].isnull()]

    # Adding back in the ones we identified as galaxies from our clustering above:
    df_gals = pd.concat([test_gals, only_na])
    df_gals.reset_index(inplace=True, drop=True)
    df_stars = test_stars.drop_duplicates()
    return df_gals, df_stars

def separateStars_South(df, plot=0, verbose=0, starcut='gentle'):
    """Star-galaxy separation in the southern hemisphere, using a simple
       SkyMapper_StarClass threshold cut.

    :param df: Dataframe of PS1 sources.
    :type df: Pandas DataFrame
    :param plot: If True, shows the separated stars and galaxies in Ap - Kron vs Ap Mag space.
    :type plot: bool, optional
    :param verbose: If true, print details of the classification routine.
    :type verbose: bool, optional
    :param starcut: Labels corresponding to the classification thresholds required to classify a star as such.
        Options are 'gentle' (P>0.8), normal (P>0.5), and aggressive (P>0.3).
    :type starcut: str

    :return: A dataframe of sources classified as galaxies.
    :rtype: Pandas DataFrame
    :return: A dataframe of sources classified as stars.
    :rtype: Pandas DataFrame
    """

    df_dropped = df[df['SkyMapper_StarClass']>0]
    only_na = df[~df.index.isin(df_dropped.index)]
    if starcut is 'normal':
        df_stars = df_dropped[df_dropped['SkyMapper_StarClass']>=0.5]
    elif starcut is 'aggressive':
        df_stars = df_dropped[df_dropped['SkyMapper_StarClass']>=0.3]
    elif starcut is 'gentle':
        df_stars = df_dropped[df_dropped['SkyMapper_StarClass']>=0.8]
    df_class_gals = df_dropped[~df_dropped.index.isin(df_stars.index)]
    df_stars.reset_index(inplace=True, drop=True)
    df_class_gals.reset_index(inplace=True, drop=True)
    df_gals = pd.concat([df_class_gals, only_na], ignore_index=True).drop_duplicates()
    return df_gals, df_stars
